.. bugyi.dummy

Welcome to bugyi.dummy's documentation!
=======================================

Dummy python project used to test the cc-python cookiecutter.

.. toctree::
   :maxdepth: -1
   :caption: Table of Contents

    API Reference <modules>
    CHANGELOG <CHANGELOG.md>
    CONTRIBUTING <CONTRIBUTING.md>
    README <README.md>


Indices and Tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
